==> forms-v5.2.1.tar.gz: forms/l10n/ja.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "フォーム",
    "{user} has shared the form {formTitle} with you" : "{user}が{formTitle}をあなたと共有しました。",
    "{user} has shared the form {formTitle} with group {group}" : "{user}はグループ {group}とフォーム {formTitle} を共有した",
    "Anonymous user" : "匿名ユーザー",
    "Nextcloud Forms" : "Nextcloud フォーム",
    "Select form" : "フォームを選択",
    "Timestamp of data load" : "データ読み込み時のタイムスタンプ",
    "No" : "いいえ",
    "Yes" : "はい",
    "Question" : "質問",
    "Answer" : "回答",
    "Copy" : "コピー",
    "Anonymous response" : "匿名の回答",
    "Shared by %s" : "%sが共有",
    "responses" : "返信",
    "User ID" : "ユーザーID",
    "User display name" : "ユーザー表示名",
    "Timestamp" : "タイムスタンプ",
    "📝 Simple surveys and questionnaires, self-hosted" : "📝 自前で作る、簡単なアンケート",
    "An error occurred while loading the forms list" : "フォームリストの読み込み中にエラーが発生しました",
    "Form not found" : "フォームがありません",
    "Unable to create a new form" : "新しいフォームを作成することはできません",
    "Unable to copy form" : "フォームをコピーできません",
    "New form" : "新しいフォーム",
    "Your forms" : "あなたのフォーム",
    "Shared with you" : "共有中",
    "Archived forms" : "アーカイブされたフォーム",
    "Loading forms …" : "フォームを読み込み中…",
    "No forms created yet" : "まだフォームが作成されていません",
    "Create a form" : "フォームの作成",
    "Select a form or create a new one" : "フォームを選択するか、新しく作成します",
    "Please select a form" : "フォームを選択してください",
    "Create new form" : "新規フォームを作成",
    "This form does not exist" : "このフォームは存在しません",
    "Form expired" : "フォームの有効期限切れ",
    "This form has expired and is no longer taking answers" : "このフォームは期限が切れており、もう回答を取得しません",
    "Form creation" : "フォームを作成",
    "Restrict form creation to selected groups" : "フォームの作成を選択したグループに制限する",
    "Select groups" : "グループを選択",
    "Form sharing" : "フォームをシェア",
    "Allow sharing by link" : "リンクによる共有を許可する",
    "Allow sharing to all logged in accounts" : "ログインしているすべてのアカウントへの共有を許可する",
    "Delete form" : "フォームを削除",
    "Form closed" : "フォームを閉じる",
    "Error while deleting {title}" : "{title} を削除中にエラー",
    "Form actions" : "フォームアクション",
    "Edit form" : "フォームを編集",
    "Share form" : "フォームを共有",
    "Results" : "結果",
    "Copy form" : "フォームをコピー",
    "Archive form" : "フォームをアーカイブ",
    "Are you sure you want to delete {title}?" : "本当に {title} を削除してもよろしいですか?",
    "Cancel" : "キャンセル",
    "Add multiple options" : "複数のオプションを追加",
    "Add multiple options (one per line)" : "複数のオプションを追加（1行ごとに1つ）",
    "Options" : "オプション",
    "Go to first page" : "最初のページへ",
    "Go to previous page" : "前のページへ",
    "Go to next page" : "次のページへ",
    "Go to last page" : "最後のページへ",
    "Answer number {index}" : "回答数 {index}",
    "Error while saving the answer" : "回答を保存中にエラーが発生しました",
    "Delete answer" : "回答を削除",
    "This question needs a title!" : "この質問にはタイトルが必須です!",
    "Question number {index}" : "質問数{index}",
    "Move question up" : "質問を上に移動",
    "Move question down" : "質問を下に移動",
    "Title of question number {index}" : "{index} 番目の設問のタイトル",
    "Required" : "必須",
    "Copy question" : "質問をコピー",
    "Delete question" : "質問の削除",
    "Description (formatting using Markdown is supported)" : "説明(Markdown 形式での入力に対応しています。)",
    "Shuffle options" : "選択肢をシャッフル",
    "Maximum file size" : "最大ファイルサイズ",
    "Delete" : "削除",
    "Uploading …" : "アップロード中...",
    "A long answer for the question “{text}”" : "質問“{text}”の複数行回答",
    "Add \"other\"" : "\"その他\"を追加",
    "Require a minimum of options to be checked" : "最低でもチェックする必要のあるオプション数",
    "Minimum options to be checked" : "最低でもチェックする必要のあるオプション数",
    "Require a maximum of options to be checked" : "最大でチェックできるオプション数",
    "Maximum options to be checked" : "最大でチェックできるオプション数",
    "Other:" : "その他:",
    "Other" : "その他",
    "A short answer for the question “{text}”" : "質問“{text}”の1行回答",
    "No response" : "返信なし",
    "Delete this response" : "この返信を削除",
    "Expired on {date}" : "{date} に有効期限が切れました。",
    "Expires on {date}" : "有効期限: {date}",
    "never" : "なし",
    "Store responses anonymously" : "回答を匿名で保存する",
    "Allow multiple responses per person" : "ユーザーごとに複数の回答を許可",
    "Set expiration date" : "有効期限を設定",
    "Close form" : "フォームを閉じる",
    "Group" : "グループ",
    "Team" : "チーム",
    "Permissions" : "アクセス権限",
    "Share link" : "リンクを共有",
    "Add link" : "リンクを追加",
    "Copy to clipboard" : "クリップボードにコピー",
    "Show QR code" : "QRコードを表示",
    "Copy embedding code" : "埋め込みコードをコピー",
    "Convert to embeddable link" : "埋め込み可能なリンクに変換する",
    "Remove link" : "リンクを削除",
    "Internal link" : "内部リンク",
    "Only works for logged in accounts with access rights" : "アクセス権を持つログインアカウントにのみ機能します",
    "Permit access to all logged in accounts" : "すべてのログイン済みアカウントからのアクセスを許可する",
    "Transfer ownership" : "所有権を譲渡する",
    "You're going to transfer the ownership of {name} to another account. Please select the account to which you want to transfer ownership." : "{name}の所有権を別のアカウントに譲渡しようとしています。所有権を譲渡するアカウントを選択してください。",
    "Search for a user" : "ユーザーを検索",
    "Type {text} to confirm." : "確認のため{text}を入力してください",
    "This can not be undone." : "これは取り消すことができません",
    "I understand, transfer this form" : "理解しました、このフォームを譲渡します",
    "View form" : "フォームを閲覧",
    "View" : "表示",
    "Edit" : "編集",
    "Show results" : "結果を表示",
    "View mode" : "表示モード",
    "Share" : "共有",
    "Responses are anonymous." : "回答者が匿名です",
    "Responses are connected to your account." : "回答はあなたのアカウントに紐付けられます。",
    "An asterisk (*) indicates mandatory questions." : "アスタリスク(*)は必須回答の設問です",
    "There was an error while adding the new question" : "設問の追加中にエラーが発生しました",
    "There was an error while removing the question" : "設問の削除中にエラーが発生しました",
    "Error while saving form" : "フォームの保存中にエラー発生",
    "Loading {title} …" : "{title} をローディング ...",
    "Form is archived" : "フォームはアーカイブされました",
    "Form title" : "フォームのタイトル",
    "Description" : "説明",
    "Add a question" : "質問を追加",
    "Summary" : "要約",
    "Responses" : "回答",
    "Unlink spreadsheet" : "スプレッドシートとのリンクを解除する",
    "Create spreadsheet" : "スプレッドシートを作成",
    "There was an error while loading the results" : "結果のロード中にエラーが発生しました",
    "File is not linked" : "ファイルが共有されていません",
    "There was an error while removing this response" : "この回答の削除中にエラーが発生しました",
    "There was an error while removing responses" : "回答の削除中にエラーが発生しました",
    "Choose spreadsheet location" : "スプレッドシートの場所を選択",
    "Create XLSX" : "XLSXを作成",
    "Create CSV" : "CSVを作成",
    "Create ODS" : "ODSを作成",
    "{amount} responses" : "{amount} 個の返信",
    "Open spreadsheet" : "スプレッドシートを開く",
    "Re-export spreadsheet" : "スプレッドシートを再エクスポート",
    "Save copy to Files" : "ファイルのコピーを保存",
    "Download" : "ダウンロード",
    "Delete all responses" : "全ての返信を削除",
    "Search" : "検索",
    "Loading responses …" : "回答をロード中 ...",
    "No results found" : "結果が見つかりません",
    "No responses yet" : "まだ返信はありません",
    "Results of submitted forms will show up here" : "送信したフォームの結果はここに表示されます",
    "Are you sure you want to delete all responses of {title}?" : "本当にすべての {title} を削除してもよろしいですか？",
    "Form settings" : "フォーム設定",
    "Sharing" : "共有",
    "Settings" : "設定",
    "Abort" : "中止",
    "Submit" : "送信",
    "Leave" : "出る",
    "Clear" : "クリア",
    "Some answers are not valid" : "いくつかの回答が無効です",
    "There was an error submitting the form" : "フォームの送信中にエラーが発生しました",
    "Submit form" : "フォームを送信",
    "Submitting form …" : "フォームを送信中...",
    "Thank you for completing the form!" : "回答のご協力ありがとうございました！",
    "Clear form" : "フォームをクリア",
    "Leave form" : "フォームから出る",
    "You have unsaved changes! Do you still want to leave?" : "保存されていない変更があります！離れるつもりですか？",
    "The form has changed since your last visit. Do you want to clear all answers?" : "前回のアクセス以降、フォームは変更されています。すべての回答をクリアしますか？",
    "Error while saving question" : "質問の保存中にエラーが発生しました",
    "There was an issue deleting this option" : "このオプションの削除中に問題が発生しました",
    "Form link copied" : "フォームのリンクをコピーしました",
    "Cannot copy, please copy the link manually" : "コピーできませんでした。手動でリンクをコピーしてください。",
    "No recommendations. Start typing." : "推奨事項はありません。 入力を開始します。",
    "No elements found." : "要素が見つかりませんでした。",
    "Checkboxes" : "チェックボックス",
    "Checkbox question title" : "設問のタイトルのチェックボックスを有効にする",
    "Enter your answer" : "あなたの回答を入力してください",
    "This question needs a title and at least one answer!" : "この質問にはタイトルと少なくとも1つの回答が必須です!",
    "Radio buttons" : "ラジオボタン",
    "Radio buttons question title" : "ラジオボタンの設問のタイトル",
    "Dropdown" : "ドロップダウン",
    "Dropdown question title" : "ドロップダウンの設問のタイトル",
    "People can pick one option" : "回答者は選択肢ひとつを選択可能",
    "Pick an option" : "選択肢を選択",
    "File" : "ファイル",
    "Short answer" : "短い回答",
    "Short answer question title" : "短文回答の設問のタイトル",
    "People can enter a short answer" : "回答者は短い回答を入力可能",
    "Long text" : "長文",
    "Long text question title" : "長文回答の設問のタイトル",
    "People can enter a long text" : "回答者は長文を入力可能",
    "Date" : "日付",
    "Date question title" : "日付回答の設問のタイトル",
    "People can pick a date" : "回答者は日付を選択可能",
    "Pick a date" : "日付を指定",
    "Datetime" : "日時",
    "Datetime question title" : "日時回答の設問のタイトル",
    "People can pick a date and time" : "回答者は日付と時刻を選択可能",
    "Pick a date and time" : "日時を選択",
    "Time" : "時間",
    "Time question title" : "時間の設問のタイトル",
    "People can pick a time" : "時間を選択できます",
    "Pick a time" : "時間を指定",
    "Color" : "色",
    "Image" : "画像",
    "Document" : "ドキュメント",
    "Presentation" : "プレゼンテーション",
    "Spreadsheet" : "スプレッドシート",
    "Text" : "テキスト",
    "Phone number" : "電話番号",
    "Enter a telephone number" : "電話番号の入力",
    "Email address" : "メールアドレス",
    "The input is not a valid email address" : "入力されたメールアドレスは無効です。",
    "Enter an email address" : "メールアドレスを入力",
    "Number" : "数字",
    "Enter a number" : "数値を入力"
},
"nplurals=1; plural=0;");

==> forms-v5.2.3.tar.gz: forms/l10n/ja.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "フォーム",
    "{user} has shared the form {formTitle} with you" : "{user}が{formTitle}をあなたと共有しました。",
    "{user} has shared the form {formTitle} with group {group}" : "{user}はグループ {group}とフォーム {formTitle} を共有した",
    "Anonymous user" : "匿名ユーザー",
    "Nextcloud Forms" : "Nextcloud フォーム",
    "Select form" : "フォームを選択",
    "Timestamp of data load" : "データ読み込み時のタイムスタンプ",
    "No" : "いいえ",
    "Yes" : "はい",
    "Question" : "質問",
    "Answer" : "回答",
    "Copy" : "コピー",
    "Anonymous response" : "匿名の回答",
    "Shared by %s" : "%sが共有",
    "responses" : "返信",
    "User ID" : "ユーザーID",
    "User display name" : "ユーザー表示名",
    "Timestamp" : "タイムスタンプ",
    "📝 Simple surveys and questionnaires, self-hosted" : "📝 自前で作る、簡単なアンケート",
    "An error occurred while loading the forms list" : "フォームリストの読み込み中にエラーが発生しました",
    "Form not found" : "フォームがありません",
    "Unable to create a new form" : "新しいフォームを作成することはできません",
    "Unable to copy form" : "フォームをコピーできません",
    "New form" : "新しいフォーム",
    "Your forms" : "あなたのフォーム",
    "Shared with you" : "共有中",
    "Archived forms" : "アーカイブされたフォーム",
    "No forms created yet" : "まだフォームが作成されていません",
    "Create a form" : "フォームの作成",
    "Select a form or create a new one" : "フォームを選択するか、新しく作成します",
    "Please select a form" : "フォームを選択してください",
    "Create new form" : "新規フォームを作成",
    "This form does not exist" : "このフォームは存在しません",
    "Form expired" : "フォームの有効期限切れ",
    "This form has expired and is no longer taking answers" : "このフォームは期限が切れており、もう回答を取得しません",
    "Form creation" : "フォームを作成",
    "Restrict form creation to selected groups" : "フォームの作成を選択したグループに制限する",
    "Select groups" : "グループを選択",
    "Form sharing" : "フォームをシェア",
    "Allow sharing by link" : "リンクによる共有を許可する",
    "Allow sharing to all logged in accounts" : "ログインしているすべてのアカウントへの共有を許可する",
    "Delete form" : "フォームを削除",
    "Form closed" : "フォームを閉じる",
    "Error while deleting {title}" : "{title} を削除中にエラー",
    "Form actions" : "フォームアクション",
    "Edit form" : "フォームを編集",
    "Share form" : "フォームを共有",
    "Results" : "結果",
    "Copy form" : "フォームをコピー",
    "Archive form" : "フォームをアーカイブ",
    "Are you sure you want to delete {title}?" : "本当に {title} を削除してもよろしいですか?",
    "Cancel" : "キャンセル",
    "Add multiple options" : "複数のオプションを追加",
    "Add multiple options (one per line)" : "複数のオプションを追加（1行ごとに1つ）",
    "Options" : "オプション",
    "Go to first page" : "最初のページへ",
    "Go to previous page" : "前のページへ",
    "Go to next page" : "次のページへ",
    "Go to last page" : "最後のページへ",
    "Answer number {index}" : "回答数 {index}",
    "Error while saving the answer" : "回答を保存中にエラーが発生しました",
    "Delete answer" : "回答を削除",
    "This question needs a title!" : "この質問にはタイトルが必須です!",
    "Question number {index}" : "質問数{index}",
    "Move question up" : "質問を上に移動",
    "Move question down" : "質問を下に移動",
    "Title of question number {index}" : "{index} 番目の設問のタイトル",
    "Required" : "必須",
    "Copy question" : "質問をコピー",
    "Delete question" : "質問の削除",
    "Description (formatting using Markdown is supported)" : "説明(Markdown 形式での入力に対応しています。)",
    "Clear selected color" : "選択した色をクリア",
    "Shuffle options" : "選択肢をシャッフル",
    "Maximum file size" : "最大ファイルサイズ",
    "Delete" : "削除",
    "Strongly disagree" : "全くそうは思わない",
    "Strongly agree" : "非常にそう思う",
    "Lowest value" : "最小値",
    "Highest value" : "最大値",
    "Label for lowest value" : "最低値のラベル",
    "Label (optional)" : "ラベル (任意)",
    "Label for highest value" : "最高値のラベル",
    "A long answer for the question “{text}”" : "質問“{text}”の複数行回答",
    "Add \"other\"" : "\"その他\"を追加",
    "Require a minimum of options to be checked" : "最低でもチェックする必要のあるオプション数",
    "Minimum options to be checked" : "最低でもチェックする必要のあるオプション数",
    "Require a maximum of options to be checked" : "最大でチェックできるオプション数",
    "Maximum options to be checked" : "最大でチェックできるオプション数",
    "Other:" : "その他:",
    "Other" : "その他",
    "A short answer for the question “{text}”" : "質問“{text}”の1行回答",
    "No response" : "返信なし",
    "Delete this response" : "この返信を削除",
    "Expired on {date}" : "{date} に有効期限が切れました。",
    "Expires on {date}" : "有効期限: {date}",
    "never" : "なし",
    "Store responses anonymously" : "回答を匿名で保存する",
    "Allow multiple responses per person" : "ユーザーごとに複数の回答を許可",
    "Set expiration date" : "有効期限を設定",
    "Close form" : "フォームを閉じる",
    "Group" : "グループ",
    "Team" : "チーム",
    "Permissions" : "アクセス権限",
    "Share link" : "リンクを共有",
    "Add link" : "リンクを追加",
    "Copy to clipboard" : "クリップボードにコピー",
    "Show QR code" : "QRコードを表示",
    "Copy embedding code" : "埋め込みコードをコピー",
    "Convert to embeddable link" : "埋め込み可能なリンクに変換する",
    "Remove link" : "リンクを削除",
    "Internal link" : "内部リンク",
    "Only works for logged in accounts with access rights" : "アクセス権を持つログインアカウントにのみ機能します",
    "Permit access to all logged in accounts" : "すべてのログイン済みアカウントからのアクセスを許可する",
    "Transfer ownership" : "所有権を譲渡する",
    "You're going to transfer the ownership of {name} to another account. Please select the account to which you want to transfer ownership." : "{name}の所有権を別のアカウントに譲渡しようとしています。所有権を譲渡するアカウントを選択してください。",
    "Search for a user" : "ユーザーを検索",
    "Type {text} to confirm." : "確認のため{text}を入力してください",
    "This can not be undone." : "これは取り消すことができません",
    "I understand, transfer this form" : "理解しました、このフォームを譲渡します",
    "View form" : "フォームを閲覧",
    "View" : "表示",
    "Edit" : "編集",
    "Show results" : "結果を表示",
    "View mode" : "表示モード",
    "Share" : "共有",
    "Responses are anonymous." : "回答者が匿名です",
    "Responses are connected to your account." : "回答はあなたのアカウントに紐付けられます。",
    "An asterisk (*) indicates mandatory questions." : "アスタリスク(*)は必須回答の設問です",
    "There was an error while adding the new question" : "設問の追加中にエラーが発生しました",
    "There was an error while removing the question" : "設問の削除中にエラーが発生しました",
    "Error while saving form" : "フォームの保存中にエラー発生",
    "Form is archived" : "フォームはアーカイブされました",
    "Form title" : "フォームのタイトル",
    "Description" : "説明",
    "Add a question" : "質問を追加",
    "Summary" : "要約",
    "Responses" : "回答",
    "Unlink spreadsheet" : "スプレッドシートとのリンクを解除する",
    "Create spreadsheet" : "スプレッドシートを作成",
    "There was an error while loading the results" : "結果のロード中にエラーが発生しました",
    "File is not linked" : "ファイルが共有されていません",
    "There was an error while removing this response" : "この回答の削除中にエラーが発生しました",
    "There was an error while removing responses" : "回答の削除中にエラーが発生しました",
    "Choose spreadsheet location" : "スプレッドシートの場所を選択",
    "Create XLSX" : "XLSXを作成",
    "Create CSV" : "CSVを作成",
    "Create ODS" : "ODSを作成",
    "{amount} responses" : "{amount} 個の返信",
    "Open spreadsheet" : "スプレッドシートを開く",
    "Re-export spreadsheet" : "スプレッドシートを再エクスポート",
    "Save copy to Files" : "ファイルのコピーを保存",
    "Download" : "ダウンロード",
    "Delete all responses" : "全ての返信を削除",
    "Search" : "検索",
    "No results found" : "結果が見つかりません",
    "No responses yet" : "まだ返信はありません",
    "Results of submitted forms will show up here" : "送信したフォームの結果はここに表示されます",
    "Are you sure you want to delete all responses of {title}?" : "本当にすべての {title} を削除してもよろしいですか？",
    "Form settings" : "フォーム設定",
    "Sharing" : "共有",
    "Settings" : "設定",
    "Abort" : "中止",
    "Submit" : "送信",
    "Leave" : "出る",
    "Clear" : "クリア",
    "Some answers are not valid" : "いくつかの回答が無効です",
    "There was an error submitting the form" : "フォームの送信中にエラーが発生しました",
    "Submit form" : "フォームを送信",
    "Thank you for completing the form!" : "回答のご協力ありがとうございました！",
    "Clear form" : "フォームをクリア",
    "Leave form" : "フォームから出る",
    "You have unsaved changes! Do you still want to leave?" : "保存されていない変更があります！離れるつもりですか？",
    "The form has changed since your last visit. Do you want to clear all answers?" : "前回のアクセス以降、フォームは変更されています。すべての回答をクリアしますか？",
    "Error while saving question" : "質問の保存中にエラーが発生しました",
    "There was an issue deleting this option" : "このオプションの削除中に問題が発生しました",
    "Form link copied" : "フォームのリンクをコピーしました",
    "Cannot copy, please copy the link manually" : "コピーできませんでした。手動でリンクをコピーしてください。",
    "No recommendations. Start typing." : "推奨事項はありません。 入力を開始します。",
    "No elements found." : "要素が見つかりませんでした。",
    "Checkboxes" : "チェックボックス",
    "Checkbox question title" : "設問のタイトルのチェックボックスを有効にする",
    "Enter your answer" : "あなたの回答を入力してください",
    "This question needs a title and at least one answer!" : "この質問にはタイトルと少なくとも1つの回答が必須です!",
    "Radio buttons" : "ラジオボタン",
    "Radio buttons question title" : "ラジオボタンの設問のタイトル",
    "Dropdown" : "ドロップダウン",
    "Dropdown question title" : "ドロップダウンの設問のタイトル",
    "People can pick one option" : "回答者は選択肢ひとつを選択可能",
    "Pick an option" : "選択肢を選択",
    "File" : "ファイル",
    "Short answer" : "短い回答",
    "Short answer question title" : "短文回答の設問のタイトル",
    "People can enter a short answer" : "回答者は短い回答を入力可能",
    "Long text" : "長文",
    "Long text question title" : "長文回答の設問のタイトル",
    "People can enter a long text" : "回答者は長文を入力可能",
    "Date" : "日付",
    "Date question title" : "日付回答の設問のタイトル",
    "People can pick a date" : "回答者は日付を選択可能",
    "Pick a date" : "日付を指定",
    "Datetime" : "日時",
    "Datetime question title" : "日時回答の設問のタイトル",
    "People can pick a date and time" : "回答者は日付と時刻を選択可能",
    "Pick a date and time" : "日時を選択",
    "Time" : "時間",
    "Time question title" : "時間の設問のタイトル",
    "People can pick a time" : "時間を選択できます",
    "Pick a time" : "時間を指定",
    "Linear scale" : "均等目盛",
    "Linear scale question title" : "均等目盛の設問のタイトル",
    "Color" : "色",
    "Color question title" : "色の設問のタイトル",
    "People can pick a color" : "色を選択できます",
    "Pick a color" : "色を選択",
    "Image" : "画像",
    "Document" : "ドキュメント",
    "Presentation" : "プレゼンテーション",
    "Spreadsheet" : "スプレッドシート",
    "Text" : "テキスト",
    "Phone number" : "電話番号",
    "Enter a telephone number" : "電話番号の入力",
    "Email address" : "メールアドレス",
    "The input is not a valid email address" : "入力されたメールアドレスは無効です。",
    "Enter an email address" : "メールアドレスを入力",
    "Number" : "数字",
    "Enter a number" : "数値を入力",
    "Loading forms …" : "フォームを読み込み中…",
    "Uploading …" : "アップロード中...",
    "Loading {title} …" : "{title} をローディング ...",
    "Loading responses …" : "回答をロード中 ...",
    "Submitting form …" : "フォームを送信中..."
},
"nplurals=1; plural=0;");
